<?php

class shopwareService
{
    private $shopwareUrl;
    private $shopwareClientId;
    private $shopwareClientSecret;

    public function __construct($shopwareUrl, $shopwareClientId, $shopwareClientSecret)
    {
        $this->shopwareUrl = $shopwareUrl;
        $this->shopwareClientId = $shopwareClientId;
        $this->shopwareClientSecret = $shopwareClientSecret;
    }

    public function addKzphSimplenote($entityId, $entityType, $username, $note)
    {
        $payload = [
            'id' => $this->createUuid(),
            'entityId' => $entityId,
            'entityType' => $entityType,
            'username' => $username,
            'note' => $note,
            'showMessage' => 0,
            'createdAt' => date('Y-m-d h:i:s')
        ];

        $this->sendRequest('/api/kzph-simplenote', json_encode($payload));
    }

    private function getToken()
    {
        $shopwareOAuthUrl = $this->shopwareUrl . '/api/oauth/token';
        $post = [
            'grant_type' => 'client_credentials',
            'client_id' => $this->shopwareClientId,
            'client_secret' => $this->shopwareClientSecret
        ];

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $shopwareOAuthUrl);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($post));
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
        $response = curl_exec($ch);
        $token = json_decode($response)->access_token;

        return $token;
    }

    private function sendRequest($path, $data, $mode = 'POST', $contentType = 'application/json', $endpoint = false)
    {
        $token = $this->getToken();
        $ch = curl_init($this->shopwareUrl . $path);

        $authorization = "Authorization: Bearer " . $token;
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type: ' . $contentType, $authorization));
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

        if ($mode == 'POST') {
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
        } else if ($mode == 'GET') {
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "GET");
        } else if ($mode == 'PATCH') {
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'PATCH');
            curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
        }

        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
        $response = curl_exec($ch);
        curl_close($ch);
        return $response;
    }

    private function createUuid()
    {
        return vsprintf('%s%s%s%s%s%s%s%s', str_split(bin2hex(random_bytes(16)), 4));
    }
}


$shopwareService = new shopwareService(
    "http://dein-shopware-shop.abc", 
    "SWIAV......", 
    "d09G....."
);

$response = $shopwareService->addKzphSimplenote(
    '7646a4cece254a2688b5c2b3df4edfef',
    'order',
    'API Schnittstelle',
    'Eine wichtige Meldung....'
);
